@@ -26,13 +26,15 @@ import boto3
 def set_arguments(service):
     parser = argparse.ArgumentParser(description="Ubirch " + service + " anchoring service")
 
-    parser.add_argument('-s', '--server', help='Choice between KAFKA or SQS, please use capslock', metavar='SQS OR KAFKA', type=str, default=None)
+    parser.add_argument('-s', '--server', help='Choice between KAFKA or SQS, please use capslock',
+                        metavar='SQS OR KAFKA', type=str, default=None)
     parser.add_argument('-ll', '--loglevel', help="log level", metavar="LOGLEVEL", default="DEBUG")
 
     if service == "ethereum":
         parser.add_argument('-pwd', '--pwd', help="password used to decrypt the Keystore File", metavar="PASSWORD",
                             type=str, default=None)
-        parser.add_argument('-kf', '--keyfile', help='location of your keyfile', metavar='PATH TO KEYFILE', type=str)
+        parser.add_argument('-kf', '--keyfile', help='location of your keyfile', metavar='PATH TO KEYFILE', type=str,
+                            default=None)
         parser.add_argument('-n', '--node', help='Eth node url to connect to', metavar='ETH NODE URL', type=str,
                             default="http://localhost:8545")
         parser.add_argument('-a', '--address', help='Ethereum address used for anchoring', metavar='ETHEREUM ADDRESS',
@@ -53,7 +55,7 @@ def set_arguments(service):
     # KAFKA config
     parser.add_argument('-p', '--port',
                         help="port of the producer or consumer, default is 9092",
-                        metavar="KAFKA PORT", default=['localhost:9092'])
+                        metavar="KAFKA PORT", default='localhost:9092')
     # SQS config
     parser.add_argument('-u', '--url',
                         help="endpoint url of the sqs server, input localhost:9324 for local connection (default)",
